@@ -2,14 +2,15 @@
 #---------------------------------------------------------------------------
 # CLASS designkey and its METHODS
 #---------------------------------------------------------------------------
-# No roxygen documentation, see directly the .Rd file
-#---------------------------------------------------------------------------
+
 # An S4 class to represent a design key solution in the planor package
-# main a single design-key solution = a list with one key matrix for each prime. Each one is an objet of class keymatrix
-#         factors: the 'designfactors' object that defines the factors
-#         model: the list of components of type c(model,estimate)
-#                containing the model and estimate specifications
-#         recursive: logical, TRUE if the design has been constructed recursively
+# SLOTS
+# -  .Data: a list with one key matrix for each prime. Each one is an objet of class keymatrix
+# -  factors: the 'designfactors' object that defines the factors
+# -  model: the list of components of type c(model,estimate)
+# -        containing the model and estimate specifications
+# -  nunits: the number of units of the design
+# -  recursive: logical, TRUE if the design has been constructed recursively
 # Methods of "designkey" : planor.design, summary, show, alias
 #---------------------------------------------------------------------------
 
@@ -20,34 +21,24 @@ setClass("designkey",
                         nunits="numeric",
                         recursive="logical"))
 ##---------------------------------------------------------------------------
-## "planor.design.designkey" help description in roxygen syntax
+## "planor.design.designkey" 
 ## ----------------------------------------------------
-#'  Build the design from a design key matrix
-#'
-#' @title Build a design from a 'designkey' object
-#'
-#' @aliases planor.design,designkey-method
-#' @name planor.design.designkey
-#' @aliases planor.design.designkey
-#' @param key an object of class  \code{\linkS4class{designkey}}
-#' @param randomize an optional formula. When set, the final design is randomized according to it.
-#' @return An object of class \code{\linkS4class{planordesign}},
-#' which  contains the design build from the input.
-#' @keywords design
-#' @author H. Monod, and al.
-#' @seealso The classes  \code{\linkS4class{planordesign}}, \code{\linkS4class{designkey} }
-#' @examples
-#' K0 <- planor.designkey(factors=c(LETTERS[1:4], "block"), nlevels=rep(3,5),
-#'   model=~block+(A+B+C+D)^2, estimate=~A+B+C+D,
-#'   nunits=3^3, base=~A+B+C, max.sol=2, verbose=TRUE)
-#' P0 <- planor.design.designkey(K0[1])
-#' P0 <- planor.design(K0[1]) ## Another way (planor.design is a method of the class designkey)
-#' P0.R <- planor.design(K0[1], randomize=~A+B+C+D) ## randomize the final design
-#' @export
-# End "planor.design.designkey" help description in roxygen syntax
+#  Build the design from a design key matrix
+# ARGUMENTS
+# - key: an object of class  designkey
+# - randomize: an optional formula. When set, the final design is randomized according to it.
+# RETURN
+# An object of class planordesign,
+# which  contains the design build from the input.
+# EXAMPLES
+# K0 <- planor.designkey(factors=c(LETTERS[1:4], "block"), nlevels=rep(3,5),
+#   model=~block+(A+B+C+D)^2, estimate=~A+B+C+D,
+#   nunits=3^3, base=~A+B+C, max.sol=2, verbose=TRUE)
+# P0 <- planor.design(K0[1]) ##  (planor.design is a method of the class designkey)
+# P0.R <- planor.design(K0[1], randomize=~A+B+C+D) ## randomize the final design
 # -------------------------------------------------------
 planor.design.designkey <- function(key, randomize=NULL, ...){
-    key@factors <- key@factors[key@factors@fact.info$model]
+ key@factors <- key@factors[key@factors@fact.info$model]
     fact.info <- key@factors@fact.info
     Ntf <- nrow(fact.info)
     LIBtf <- rownames(fact.info)
@@ -61,7 +52,7 @@ planor.design.designkey <- function(key, randomize=NULL, ...){
 
     ## A. Construction of each sub-design associated with each Sylow subgroup
 
-    ##PVuqf <- unique(pseudo.info$nlev)
+    
     PVuqf <- unique(factorize(key@nunits))
 
     PVuqf <- PVuqf[order(PVuqf)]
@@ -92,15 +83,15 @@ planor.design.designkey <- function(key, randomize=NULL, ...){
         b.back[i,FACTtpf[i]] <- prod( NIVtpf[select] )
     }
     b.finaldesign <- multBig(b.fullpseudodesign, b.back)
-    ## Transformation de b.finaldesign en non big matrix
-    ## car il est factor
+    
+    
     b.finaldesign <- as.data.frame(b.finaldesign[,])
 
-    names(b.finaldesign) <- LIBtf ## noms des colonnes
+    names(b.finaldesign) <- LIBtf ## columns names
     for(i in seq_len(Ntf)){
         zz <- factor(b.finaldesign[,i])
         levels(zz) <- (key@factors@levels)[[i]]
-        b.finaldesign[i] <- zz ## transfo de la colonne i en facteur
+        b.finaldesign[i] <- zz ## convert column i into factor
     }
 
     ## E. Randomization, if required
@@ -124,50 +115,30 @@ planor.design.designkey <- function(key, randomize=NULL, ...){
 
 
     return(OUT)
-} ## fin planor.design.designkey
+} ## end planor.design.designkey
 ##------------------------------------------------------------------------
-#' Method planor.design for "designkey"
-#'
-#' @title  Method planor.design for "designkey"
-#'
-#' @name planor.design-method.designkey
-#' @aliases planor.design-method.designkey
 setMethod("planor.design", signature(key="designkey"),
           definition=planor.design.designkey)
 ##--------------------------------------------------------------------------
 
 
-# "summary.designkey" help description in roxygen syntax
-#' Summarises the design properties of a \code{\linkS4class{designkey}} object, by
-#' printing the summary of each of its key matrices (design key matrix, confounding
-#' and aliasing relationships)
-#'
-#' @aliases summary,designkey-method
-#' @name summary.designkey
-#' @aliases summary.designkey
-#' @title  Summarise the design properties of a 'designkey' object
-#'   @param object an object of class \code{\linkS4class{designkey}}
-#'   @param \ldots ignored
-#' @return
-#'     A list of matrices, one per prime. Their columns are kernel generators of the key matrices
-#' @author H. Monod, and al.
-#' @seealso  The class \code{\linkS4class{designkey}}; \code{\link{summary.keymatrix}}
-#' @examples
-#' K0 <- planor.designkey(factors=c(LETTERS[1:4], "block"), nlevels=rep(3,5),
-#'    model=~block+(A+B+C+D)^2, estimate=~A+B+C+D,
-#'    nunits=3^3, base=~A+B+C, max.sol=2)
-#' resum <- summary(K0[1])
-#' @keywords  design
-#' @export
-# "End summary.designkey" help description in roxygen syntax
+# "summary.designkey" 
+# Summarises the design properties of a designkey object, by
+# printing the summary of each of its key matrices (design key matrix, confounding
+# and aliasing relationships)
+# EXAMPLES
+# K0 <- planor.designkey(factors=c(LETTERS[1:4], "block"), nlevels=rep(3,5),
+#    model=~block+(A+B+C+D)^2, estimate=~A+B+C+D,
+#    nunits=3^3, base=~A+B+C, max.sol=2)
+# resum <- summary(K0[1])
 # ---------------------------------------------
 
 summary.designkey <- function(object,show="dtbw", save="k", ...){
   ## NOTE: the formal argument list "(object, ...)" is
   ## required to be compatible with the generic function
   ## "summary" in R;
-  ## Is some display required?
 
+  ## Is some display required?
   isshow <-  (length(show) >0 && show != "" &&
     grepl("[d,t,b,w]", show, ignore.case=TRUE))
   ## Is some output required?
@@ -188,7 +159,7 @@ summary.designkey <- function(object,show="dtbw", save="k", ...){
   BLOCKtpf <- pseudo.info$block
   ## units factors
 
-  ##PVuqf <- unique(pseudo.info$nlev)
+  
   PVuqf <- unique(factorize(object@nunits))
 
   PVuqf <- PVuqf[order(PVuqf)]
@@ -209,62 +180,45 @@ summary.designkey <- function(object,show="dtbw", save="k", ...){
     if (issave) {
       Hgen[[k]] <- retour
     }
-  } ## fin k
+  } ## end k
 
     if (issave) {
       names(Hgen)  <- paste("Prime",  PVuqf[1:Nuqf])
       return(invisible(Hgen))
     } else  return(invisible())
-} ## fin summary.designkey
+} ## end summary.designkey
 
 ##--------------------------------------------------------------------------
-#' Method summary for "designkey"
-#'
-#' @title  Method summary for "designkey"
-#'
-#' @name summary-method.designkey
-#' @aliases summary-method.designkey
 setMethod("summary", signature(object="designkey"),
           definition=summary.designkey)
 ##--------------------------------------------------------------------------
-# "show.designkey" help description in roxygen syntax
-#' Print the design key matrices of an object of class \code{\linkS4class{designkey}}
-#'
-#' @aliases show,designkey-method
-#' @name show.designkey
-#' @aliases show.designkey
-#' @title  Print the design key matrices of a 'designkey' object
-#'   @param object an object of class \code{\linkS4class{designkey}}
-#' @return
-#' \sQuote{show} returns an invisible \sQuote{NULL}.
-#' @author H. Monod, and al.
-#' @seealso  \code{\link{summary.designkey}} and the class \code{\linkS4class{designkey}}
-#' @note
-#' - The number of rows and columns of the matrices that are printed
-#' are limited by the option \code{planor.max.print}
-#'
-#' -  Objects of class \code{\linkS4class{designkey}} are displayed automatically is if by a call to 'show'.
-#' @examples
-#' K0 <- planor.designkey(factors=c(LETTERS[1:4], "block"), nlevels=rep(3,5),
-#'    model=~block+(A+B+C+D)^2, estimate=~A+B+C+D ,
-#'    nunits=3^3, base=~A+B+C, max.sol=2)
-#' ## The method will now be used for automatic printing of a component of K0
-#' K0[1]
-#' show(K0[1]) ## idem
-#' print(K0[1]) ## idem
-#' @keywords  design
-#' @export
-# "End show.designkey" help description in roxygen syntax
+# "show.designkey" 
+# Print the design key matrices of an object of class designkey
+#
+# RETURN
+# show returns an invisible NULL.
+# NOTE
+# - The number of rows and columns of the matrices that are printed
+# are limited by the option planor.max.print
+#
+# -  Objects of class designkey are displayed automatically by invocation of ‘show’
+# EXAMPLES
+# K0 <- planor.designkey(factors=c(LETTERS[1:4], "block"), nlevels=rep(3,5),
+#    model=~block+(A+B+C+D)^2, estimate=~A+B+C+D ,
+#    nunits=3^3, base=~A+B+C, max.sol=2)
+# ## The method will now be used for automatic printing of a component of K0
+# K0[1]
+# show(K0[1]) ## idem
+# print(K0[1]) ## idem
 # ---------------------------------------------
 show.designkey <- function(object){
   ## NOTE: the formal argument list "(object)" is
-  ## required to be compatible with the generic function
-  ##  in R;
-  ## units factors
+  ## required to be compatible with the generic function  in R;
+  ## -----------------------------------------------
   cat("An object of class designkey\n")
   keys <- unclass(object)
   primes <- as.integer( names(keys) )
-  ##cat("DESIGN KEY MATRICES\n")
+  
 
   ## A. Design key matrices
   for(k in seq(length(primes))) {
@@ -272,44 +226,28 @@ show.designkey <- function(object){
     printgmat(keys[[k]])
   }
   invisible()
-} ## fin show.designkey
+} ## end show.designkey
 
 ##--------------------------------------------------------------------------
-#' Method show for "designkey"
-#'
-#' @title  Method show for "designkey"
-#'
-#' @name show-method.designkey
-#' @aliases show-method.designkey
 setMethod("show", signature(object="designkey"),
           definition=show.designkey)
 
 ##--------------------------------------------------------------------------
 
 
-# "alias.designkey" help description in roxygen syntax
-#' Summarise the design properties from a design key matrix.
-#' Display the design keys matrices and the factorial effects confounded with the mean.
-#'
-#' @aliases alias,designkey-method
-#' @name alias.designkey
-#' @aliases alias.designkey
-#' @title Prints the aliases of a 'designkey' object
-#'   @param object an object of class \code{\linkS4class{designkey}}
-#'   @param model an optional model formula (by default the first model in object)
-#'   @param \ldots ignored
-#' @return
-#'     invisible
-#' @author H. Monod, and al.
-#' @seealso  The class \code{\linkS4class{designkey}}
-#' @examples
-#' K0 <- planor.designkey(factors=c(LETTERS[1:4], "block"), nlevels=rep(3,5),
-#'    model=~block+(A+B+C+D)^2, estimate=~A+B+C+D,
-#'    nunits=3^3, base=~A+B+C, max.sol=2)
-#' alias(K0[1])
-#' @keywords  design
-#' @export
-# "End alias.designkey" help description in roxygen syntax
+# "alias.designkey" 
+# Summarise the design properties from a design key matrix.
+# Display the design keys matrices and the factorial effects confounded with the mean.
+# ARGUMENTS
+#    model: an optional model formula (by default the first model in object)
+#    ...: ignored
+# RETURN
+#     invisible
+# EXAMPLES
+# K0 <- planor.designkey(factors=c(LETTERS[1:4], "block"), nlevels=rep(3,5),
+#    model=~block+(A+B+C+D)^2, estimate=~A+B+C+D,
+#    nunits=3^3, base=~A+B+C, max.sol=2)
+# alias(K0[1])
 # ---------------------------------------------
 
 alias.designkey <- function(object, model, ...){
@@ -368,24 +306,18 @@ alias.designkey <- function(object, model, ...){
     modset <- matrix(b.modset[rows.k, ], ncol=ncol(b.modset))
     model.cols.k <-
       0 < apply(modset, 2, sum)
-# BUG fixed 30/4/2013    model.k <- modset[rows.k, model.cols.k, drop=FALSE]
+
     model.k <- modset[, model.cols.k, drop=FALSE]
     ## alias calculations for prime p
     alias.keymatrix(object=object[[k]], model=model.k,
                     fact=FACTtpf[rows.k],
                     block=BLOCKtpf[rows.k])
-  } ## fin k
+  } ## end k
 
   return(invisible())
-} ## fin alias.designkey
+} ## end alias.designkey
 
 ##--------------------------------------------------------------------------
-#' Method alias for "designkey"
-#'
-#' @title  Method alias for "designkey"
-#'
-#' @name alias-method.designkey
-#' @aliases alias-method.designkey
 setMethod("alias", signature(object="designkey"),
           definition=alias.designkey)
 ##--------------------------------------------------------------------------
